---
title: Promptflow
sidebarTitle: Promptflow
---

Promptflow is a comprehensive suite of tools that simplifies the development, testing, evaluation, and deployment of LLM based AI applications. It also supports integration with Azure AI for cloud-based operations and is designed to streamline end-to-end development.

Refer to [Promptflow docs](https://microsoft.github.io/promptflow/) for more information.

Quick links:

- Why use Promptflow - [Link](https://learn.microsoft.com/en-us/azure/machine-learning/prompt-flow/overview-what-is-prompt-flow)
- Quick start guide - [Link](https://microsoft.github.io/promptflow/how-to-guides/quick-start.html)

## Sample Flow

![Sample Promptflow](./img/ecosystem-promptflow.png)
